==> tool-sql-2.6.0-pre-sources.jar: io/ciera/tool/sql/architecture/interfaces/PortSet.java <==
package io.ciera.tool.sql.architecture.interfaces;


import io.ciera.runtime.summit.classes.IInstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.architecture.component.ComponentDefinitionSet;
import io.ciera.tool.sql.architecture.file.FileSet;
import io.ciera.tool.sql.architecture.interfaces.IfaceSet;
import io.ciera.tool.sql.architecture.interfaces.PortMessageSet;
import io.ciera.tool.sql.architecture.interfaces.PortSet;
import io.ciera.tool.sql.ooaofooa.component.C_POSet;


public interface PortSet extends IInstanceSet<PortSet,Port> {

    // attributes
    public void setPort_name( String m_port_name ) throws XtumlException;
    public void setProvider( boolean m_provider ) throws XtumlException;
    public void setName( String ref_name ) throws XtumlException;
    public void setIface_package( String ref_iface_package ) throws XtumlException;
    public void setProvider_port_name( String ref_provider_port_name ) throws XtumlException;
    public void setComp_package( String ref_comp_package ) throws XtumlException;
    public void setProvider_port_package( String ref_provider_port_package ) throws XtumlException;
    public void setBase_class( String m_base_class ) throws XtumlException;
    public void setPackage( String ref_package ) throws XtumlException;
    public void setPort_Id( UniqueId ref_port_Id ) throws XtumlException;
    public void setIface_name( String ref_iface_name ) throws XtumlException;
    public void setComp_name( String ref_comp_name ) throws XtumlException;


    // selections
    public FileSet R401_is_a_File() throws XtumlException;
    public PortSet R4160_satisfies_provided_Port() throws XtumlException;
    public PortSet R4160_satisfies_required_Port() throws XtumlException;
    public ComponentDefinitionSet R417_passes_messages_for_ComponentDefinition() throws XtumlException;
    public IfaceSet R418_implements_Iface() throws XtumlException;
    public PortMessageSet R420_provides_implementation_for_PortMessage() throws XtumlException;
    public C_POSet R422_is_transformed_from_C_PO() throws XtumlException;


}

==> tool-sql-2.7.0-sources.jar: io/ciera/tool/sql/architecture/interfaces/PortSet.java <==
package io.ciera.tool.sql.architecture.interfaces;


import io.ciera.runtime.summit.classes.IInstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.tool.sql.architecture.component.ComponentDefinitionSet;
import io.ciera.tool.sql.architecture.file.FileSet;
import io.ciera.tool.sql.architecture.interfaces.IfaceSet;
import io.ciera.tool.sql.architecture.interfaces.PortMessageSet;
import io.ciera.tool.sql.architecture.interfaces.PortSet;
import io.ciera.tool.sql.ooaofooa.component.C_POSet;


public interface PortSet extends IInstanceSet<PortSet,Port> {

    // attributes
    public void setProvider( boolean m_provider ) throws XtumlException;
    public void setProvider_port_package( String ref_provider_port_package ) throws XtumlException;
    public void setPackage( String ref_package ) throws XtumlException;
    public void setBase_class( String m_base_class ) throws XtumlException;
    public void setIface_name( String ref_iface_name ) throws XtumlException;
    public void setComp_package( String ref_comp_package ) throws XtumlException;
    public void setName( String ref_name ) throws XtumlException;
    public void setProvider_port_name( String ref_provider_port_name ) throws XtumlException;
    public void setEndpoint( String m_endpoint ) throws XtumlException;
    public void setComp_name( String ref_comp_name ) throws XtumlException;
    public void setPort_name( String m_port_name ) throws XtumlException;
    public void setIface_package( String ref_iface_package ) throws XtumlException;
    public void setImpl_class( String m_impl_class ) throws XtumlException;


    // selections
    public FileSet R401_is_a_File() throws XtumlException;
    public PortSet R4160_satisfies_provided_Port() throws XtumlException;
    public PortSet R4160_satisfies_required_Port() throws XtumlException;
    public ComponentDefinitionSet R417_passes_messages_for_ComponentDefinition() throws XtumlException;
    public IfaceSet R418_implements_Iface() throws XtumlException;
    public PortMessageSet R420_provides_implementation_for_PortMessage() throws XtumlException;
    public C_POSet R422_C_PO() throws XtumlException;


}
